@@ -23,7 +23,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGAdvicePluginFactory, registerPlugin<SKGAdvicePlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGAdvicePlugin, "metadata.json")
 
 SKGAdvicePlugin::SKGAdvicePlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), currentDocument(nullptr)
 {
