@@ -29,7 +29,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGBookmarkPluginFactory, registerPlugin<SKGBookmarkPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGBookmarkPlugin, "metadata.json")
 
 SKGBookmarkPlugin::SKGBookmarkPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& iArg) :
     SKGInterfacePlugin(iParent), m_currentDocument(nullptr), m_dockWidget(nullptr), m_bookmarkMenu(nullptr)
