@@ -23,7 +23,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGHighlightPluginFactory, registerPlugin<SKGHighlightPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGHighlightPlugin, "metadata.json")
 
 SKGHighlightPlugin::SKGHighlightPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
