@@ -98,6 +98,11 @@ public:
      */
     bool isInPagesChooser() const override;
 
+    /**
+     * Must be modified to close properly the plugin.
+     */
+    virtual void close() override;
+
 private Q_SLOTS:
     void refreshMainPage();
 
