@@ -244,15 +244,26 @@ void SKGPropertiesPluginDockWidget::onAddProperty()
         QVariant blob;
         QFile file(value);
         if (file.exists()) {
+#ifdef SKG_KF_5100
+            int mode = KMessageBox::questionTwoActionsCancel(this, i18nc("Question", "Do you want copy or link the file?"),
+                       QString(),
+                       KGuiItem(i18nc("Question", "Copy"), QStringLiteral("edit-copy")),
+                       KGuiItem(i18nc("Question", "Link"), QStringLiteral("edit-link")));
+            if (mode == KMessageBox::SecondaryAction) {
+                return;
+            }
+            if (mode == KMessageBox::PrimaryAction) {
+#else
             int mode = KMessageBox::questionYesNoCancel(this, i18nc("Question", "Do you want copy or link the file?"),
                        QString(),
                        KGuiItem(i18nc("Question", "Copy"), QStringLiteral("edit-copy")),
                        KGuiItem(i18nc("Question", "Link"), QStringLiteral("edit-link")));
-
             if (mode == KMessageBox::Cancel) {
                 return;
             }
             if (mode == KMessageBox::Yes) {
+#endif
+
                 // Value is a file name ==> blob
                 if (Q_UNLIKELY(!file.open(QIODevice::ReadOnly))) {
                     err = SKGError(ERR_INVALIDARG, i18nc("Error message: could not open the requested file", "Open file '%1' failed", value));
