@@ -24,7 +24,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGSelectAllPluginFactory, registerPlugin<SKGSelectAllPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGSelectAllPlugin, "metadata.json")
 
 SKGSelectAllPlugin::SKGSelectAllPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent), m_currentDocument(nullptr), m_selectionMessage(nullptr)
