@@ -32,7 +32,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGStatisticPluginFactory, registerPlugin<SKGStatisticPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGStatisticPlugin, "metadata.json")
 
 SKGStatisticPlugin::SKGStatisticPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent), m_currentDocument(nullptr)
