@@ -28,7 +28,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGUndoRedoPluginFactory, registerPlugin<SKGUndoRedoPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGUndoRedoPlugin, "metadata.json")
 
 SKGUndoRedoPlugin::SKGUndoRedoPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
@@ -154,24 +154,30 @@ void SKGUndoRedoPlugin::refresh()
     }
 }
 
-
-QWidget* SKGUndoRedoPlugin::getPreferenceWidget()
+void SKGUndoRedoPlugin::initPreferences()
 {
-    SKGTRACEINFUNC(10)
     // Read Setting
     if (m_currentDocument != nullptr) {
         KSharedConfigPtr config = KSharedConfig::openConfig();
         KConfigGroup pref = config->group("skg_undoredo");
         pref.writeEntry("maxNumberOfUndo", SKGServices::stringToInt(m_currentDocument->getParameter(QStringLiteral("SKG_UNDO_MAX_DEPTH"))));
         pref.writeEntry("cleanHistoryOnSave", (m_currentDocument->getParameter(QStringLiteral("SKG_UNDO_CLEAN_AFTER_SAVE")) == QStringLiteral("Y")));
-    }
 
+        skgundoredo_settings::self()->read();
+    }
+}
+
+
+QWidget* SKGUndoRedoPlugin::getPreferenceWidget()
+{
+    SKGTRACEINFUNC(10)
     // Create widget
     auto w = new QWidget();
     ui.setupUi(w);
     return w;
 }
 
+
 KConfigSkeleton* SKGUndoRedoPlugin::getPreferenceSkeleton()
 {
     return skgundoredo_settings::self();
