@@ -48,6 +48,11 @@ public:
      */
     void refresh() override;
 
+    /**
+     * Initialize the preferences. This is use full for settings stored in the document
+     */
+    virtual void initPreferences() override;
+
     /**
      * The preference widget of the plugin.
      * @return The preference widget of the plugin
