@@ -32,7 +32,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGImportPluginBackendFactory, registerPlugin<SKGImportPluginBackend>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginBackend, "metadata.json")
 
 SKGImportPluginBackend::SKGImportPluginBackend(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
@@ -41,6 +41,7 @@ SKGImportPluginBackend::SKGImportPluginBackend(QObject* iImporter, const QVarian
     Q_UNUSED(iArg)
 
     m_listBackends = KServiceTypeTrader::self()->query(QStringLiteral("Skrooge/Import/Backend"));
+    SKGTRACEL(10) << m_listBackends.count() << " plugins found" << SKGENDL;
 }
 
 SKGImportPluginBackend::~SKGImportPluginBackend()
@@ -75,7 +76,7 @@ QString SKGImportPluginBackend::getParameter(const QString& iAttribute)
 bool SKGImportPluginBackend::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer == nullptr ? true : getService().data() != nullptr);
+    return (m_importer->getDocument() == nullptr ? true : getService().data() != nullptr);
 }
 
 struct download {
@@ -131,7 +132,7 @@ struct download {
 
 SKGError SKGImportPluginBackend::importFile()
 {
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
