@@ -28,7 +28,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGImportPluginGncFactory, registerPlugin<SKGImportPluginGnc>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginGnc, "metadata.json")
 
 SKGImportPluginGnc::SKGImportPluginGnc(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
@@ -43,7 +43,7 @@ SKGImportPluginGnc::~SKGImportPluginGnc()
 bool SKGImportPluginGnc::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return true;
     }
     QString extension = m_importer->getFileNameExtension();
@@ -52,7 +52,7 @@ bool SKGImportPluginGnc::isImportPossible()
 
 SKGError SKGImportPluginGnc::importFile()
 {
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
