@@ -22,7 +22,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGImportPluginJsonFactory, registerPlugin<SKGImportPluginJson>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginJson, "metadata.json")
 
 SKGImportPluginJson::SKGImportPluginJson(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
@@ -37,7 +37,7 @@ SKGImportPluginJson::~SKGImportPluginJson()
 bool SKGImportPluginJson::isExportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("JSON"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("JSON"));
 }
 
 SKGError SKGImportPluginJson::exportFile()
