@@ -51,7 +51,7 @@ QMap<QString, SKGPayeeObject> SKGImportPluginKmy::m_mapIdPayee;
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGImportPluginKmyFactory, registerPlugin<SKGImportPluginKmy>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginKmy, "metadata.json")
 
 SKGImportPluginKmy::SKGImportPluginKmy(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
@@ -669,7 +669,7 @@ SKGError SKGImportPluginKmy::importAccounts(SKGBankObject& bank, SKGAccountObjec
 
 SKGError SKGImportPluginKmy::importFile()
 {
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
 
@@ -761,7 +761,7 @@ SKGError SKGImportPluginKmy::importFile()
 bool SKGImportPluginKmy::isExportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("KMY"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("KMY"));
 }
 
 SKGError SKGImportPluginKmy::exportHeader(QDomDocument& doc, QDomElement& root)
@@ -1494,7 +1494,7 @@ SKGError SKGImportPluginKmy::exportFile()
     // Initialisation
     m_opTreated.clear();
 
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
