@@ -15,7 +15,6 @@
 
 #include <qsavefile.h>
 #include <qfile.h>
-#include <qdom.h>
 #include <qprocess.h>
 #include <qdir.h>
 #include <quuid.h>
@@ -28,7 +27,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGImportPluginLedgerFactory, registerPlugin<SKGImportPluginLedger>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginLedger, "metadata.json")
 
 SKGImportPluginLedger::SKGImportPluginLedger(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
@@ -45,7 +44,7 @@ SKGImportPluginLedger::~SKGImportPluginLedger()
 bool SKGImportPluginLedger::isExportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("LEDGER"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("LEDGER"));
 }
 
 SKGError SKGImportPluginLedger::exportFile()
@@ -216,7 +215,7 @@ SKGError SKGImportPluginLedger::exportFile()
 bool SKGImportPluginLedger::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("LEDGER"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("LEDGER"));
 }
 
 bool SKGImportPluginLedger::isAccount(const QString& type)
@@ -226,7 +225,7 @@ bool SKGImportPluginLedger::isAccount(const QString& type)
 
 SKGError SKGImportPluginLedger::importFile()
 {
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
