@@ -34,7 +34,7 @@ QMap<QString, SKGPayeeObject> SKGImportPluginMny::m_mapIdPayee;
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGImportPluginMnyFactory, registerPlugin<SKGImportPluginMny>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginMny, "metadata.json")
 
 SKGImportPluginMny::SKGImportPluginMny(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
@@ -75,7 +75,7 @@ bool SKGImportPluginMny::removeDir(const QString& dirName)
 bool SKGImportPluginMny::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return true;
     }
     QString extension = m_importer->getFileNameExtension();
@@ -103,7 +103,7 @@ SKGError SKGImportPluginMny::readJsonFile(const QString& iFileName, QVariant& oV
 
 SKGError SKGImportPluginMny::importFile()
 {
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
 
