@@ -31,7 +31,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGImportPluginQifFactory, registerPlugin<SKGImportPluginQif>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginQif, "metadata.json")
 
 SKGImportPluginQif::SKGImportPluginQif(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
@@ -54,7 +54,7 @@ bool SKGImportPluginQif::isImportPossible()
 
 SKGError SKGImportPluginQif::importFile()
 {
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
 
@@ -924,12 +924,12 @@ SKGError SKGImportPluginQif::importFile()
 bool SKGImportPluginQif::isExportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("QIF"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("QIF"));
 }
 
 SKGError SKGImportPluginQif::exportFile()
 {
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
