@@ -31,7 +31,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGImportPluginSkgFactory, registerPlugin<SKGImportPluginSkg>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGImportPluginSkg, "metadata.json")
 
 SKGImportPluginSkg::SKGImportPluginSkg(QObject* iImporter, const QVariantList& iArg)
     : SKGImportPlugin(iImporter)
@@ -48,12 +48,12 @@ SKGImportPluginSkg::~SKGImportPluginSkg()
 bool SKGImportPluginSkg::isImportPossible()
 {
     SKGTRACEINFUNC(10)
-    return (m_importer == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("SKG") || m_importer->getFileNameExtension() == QStringLiteral("SQLITE") || m_importer->getFileNameExtension() == QStringLiteral("SQLCIPHER"));
+    return (m_importer->getDocument() == nullptr ? true : m_importer->getFileNameExtension() == QStringLiteral("SKG") || m_importer->getFileNameExtension() == QStringLiteral("SQLITE") || m_importer->getFileNameExtension() == QStringLiteral("SQLCIPHER"));
 }
 
 SKGError SKGImportPluginSkg::importFile()
 {
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
@@ -448,7 +448,7 @@ bool SKGImportPluginSkg::isExportPossible()
 
 SKGError SKGImportPluginSkg::exportFile()
 {
-    if (m_importer == nullptr) {
+    if (m_importer->getDocument() == nullptr) {
         return SKGError(ERR_ABORT, i18nc("Error message", "Invalid parameters"));
     }
     SKGError err;
