@@ -649,7 +649,11 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                     IFOKDO(err, accountObj.save())
                 } else {
                     // The bank does not exist
+#ifdef SKG_KF_5100
+                    int code = KMessageBox::PrimaryAction;
+#else
                     int code = KMessageBox::Yes;
+#endif
                     SKGBankObject currentBank;
                     err = accountObj.getBank(currentBank);
                     IFOK(err) {
@@ -657,13 +661,25 @@ void SKGBankPluginWidget::onModifyAccountClicked()
                         err = currentBank.getAccounts(accounts);
                         if (!err && accounts.count() > 1) {
                             QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+#ifdef SKG_KF_5100
+                            code = KMessageBox::questionTwoActions(this,
+                                                                   i18nc("Question", "You are trying to modify bank name of account named '%1'.\nDo you want to do this modification for all accounts of this bank ? ",  accountObj.getName()),
+                                                                   i18nc("Question",  "Do you want to modify the account ?"),
+                                                                   KStandardGuiItem::apply(), KStandardGuiItem::cancel()
+                                                                  );
+#else
                             code = KMessageBox::questionYesNo(this, i18nc("Question", "You are trying to modify bank name of account named '%1'.\nDo you want to do this modification for all accounts of this bank ? ",  accountObj.getName()));
+#endif
                             QApplication::restoreOverrideCursor();
                         }
                     }
 
                     IFOKDO(err, accountObj.getBank(bankObj))
+#ifdef SKG_KF_5100
+                    if (code == KMessageBox::PrimaryAction) {
+#else
                     if (code == KMessageBox::Yes) {
+#endif
                         // The bank does not exist ==> update this one
                         IFOKDO(err, bankObj.setName(bankName))
                     } else {
