@@ -24,7 +24,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGCalculatorPluginFactory, registerPlugin<SKGCalculatorPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGCalculatorPlugin, "metadata.json")
 
 SKGCalculatorPlugin::SKGCalculatorPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
 {
