@@ -32,7 +32,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGCategoriesPluginFactory, registerPlugin<SKGCategoriesPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGCategoriesPlugin, "metadata.json")
 
 SKGCategoriesPlugin::SKGCategoriesPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
     : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
