@@ -39,7 +39,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGImportExportPluginFactory, registerPlugin<SKGImportExportPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGImportExportPlugin, "metadata.json")
 
 SKGImportExportPlugin::SKGImportExportPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
@@ -209,11 +209,19 @@ QStringList SKGImportExportPlugin::processArguments(const QStringList& iArgument
         QString extension = QFileInfo(filename).suffix().toUpper();
         QString extensionDocument = m_currentBankDocument->getFileExtension().toUpper();
         if (QFile(filename).exists() && extension != extensionDocument) {
+#ifdef SKG_KF_5100
+            int rc = KMessageBox::questionTwoActions(SKGMainPanel::getMainPanel(), i18nc("Question",  "Do you really want to import %1 into the current document ?", filename),
+                     i18nc("Question",  "Import confirmation"),
+                     KStandardGuiItem::apply(), KStandardGuiItem::cancel(),
+                     QStringLiteral("importconfirmation"));
+            if (rc == KMessageBox::PrimaryAction) {
+#else
             int rc = KMessageBox::questionYesNo(SKGMainPanel::getMainPanel(), i18nc("Question",  "Do you really want to import %1 into the current document ?", filename),
                                                 i18nc("Question",  "Import confirmation"),
                                                 KStandardGuiItem::yes(), KStandardGuiItem::no(),
                                                 QStringLiteral("importconfirmation"));
             if (rc == KMessageBox::Yes) {
+#endif
                 Q_EMIT importFileName(filename);
                 output.pop_back();
             }
@@ -222,9 +230,23 @@ QStringList SKGImportExportPlugin::processArguments(const QStringList& iArgument
     return output;
 }
 
+void SKGImportExportPlugin::initPreferences()
+{
+    // Read Setting
+    if (m_currentBankDocument != nullptr) {
+        KSharedConfigPtr config = KSharedConfig::openConfig();
+        KConfigGroup pref = config->group("skrooge_importexport");
+        auto backends = m_currentBankDocument->getParameter(QStringLiteral("SKG_BACKENDS"));
+        pref.writeEntry("backends", backends);
+
+        skgimportexport_settings::self()->read();
+    }
+}
+
 QWidget* SKGImportExportPlugin::getPreferenceWidget()
 {
     SKGTRACEINFUNC(10)
+    // Create widget
     auto w = new QWidget();
     ui.setupUi(w);
     connect(ui.kcfg_automatic_search_header, &QCheckBox::toggled, ui.kHeaderPositionFrm, &QFrame::setHidden);
@@ -243,7 +265,7 @@ QWidget* SKGImportExportPlugin::getPreferenceWidget()
     QString doc;
     const auto services = KServiceTypeTrader::self()->query(QStringLiteral("Skrooge/Import/Backend"));
     for (const auto& service : services) {
-        auto os_supported = SKGServices::splitCSVLine(service->property(QStringLiteral("X-SKROOGE-ossuppored"), QVariant::String).toString().toLower(), QLatin1Char(','));
+        auto os_supported = SKGServices::splitCSVLine(service->property(QStringLiteral("X-SKROOGE-ossupported"), QVariant::String).toString().toLower(), QLatin1Char(','));
         if (os_supported.isEmpty() || os_supported.contains(QSysInfo::kernelType().toLower())) {
             doc += "<br/><b>" + service->property(QStringLiteral("X-Krunner-ID"), QVariant::String).toString().toLower() + "</b><br/>";
             doc += service->property(QStringLiteral("Name"), QVariant::String).toString() + "<br/>";
@@ -279,6 +301,21 @@ KConfigSkeleton* SKGImportExportPlugin::getPreferenceSkeleton()
     return skgimportexport_settings::self();
 }
 
+SKGError SKGImportExportPlugin::savePreferences() const
+{
+    SKGError err;
+    if (m_currentBankDocument != nullptr) {
+        // Read Setting
+        auto backends = skgimportexport_settings::backends();
+
+        // Save setting in document
+        if (backends != m_currentBankDocument->getParameter(QStringLiteral("SKG_BACKENDS"))) {
+            err = m_currentBankDocument->setParameter(QStringLiteral("SKG_BACKENDS"), backends);
+        }
+    }
+    return err;
+}
+
 QString SKGImportExportPlugin::title() const
 {
     return i18nc("Noun", "Import / Export");
@@ -470,7 +507,7 @@ void SKGImportExportPlugin::importFiles(const QList<QUrl>& iFiles, int mode, boo
             // Panel to ask files
             KEncodingFileDialog::Result result = KEncodingFileDialog::getOpenUrlsAndEncoding(lastCodecUsed, QUrl(QStringLiteral("kfiledialog:///IMPEXP")),
                                                  mode == 2 || mode == 3 ? QString("*.csv|" % i18nc("A file format", "CSV Files")) :
-                                                 SKGImportExportManager::getImportMimeTypeFilter(),
+                                                 SKGImportExportManager().getImportMimeTypeFilter(),
                                                  SKGMainPanel::getMainPanel());
             const auto urls = result.URLs;
             fileNames.reserve(urls.count());
@@ -656,7 +693,7 @@ void SKGImportExportPlugin::exportFile()
         if (lastCodecUsed.isEmpty()) {
             lastCodecUsed = QTextCodec::codecForLocale()->name();
         }
-        QString fileName = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"), SKGImportExportManager::getExportMimeTypeFilter(),
+        QString fileName = SKGMainPanel::getSaveFileName(QStringLiteral("kfiledialog:///IMPEXP"), SKGImportExportManager().getExportMimeTypeFilter(),
                            SKGMainPanel::getMainPanel(), &lastCodecUsed);
         if (fileName.isEmpty() || (m_currentBankDocument == nullptr)) {
             return;
