@@ -44,7 +44,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGOperationPluginFactory, registerPlugin<SKGOperationPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGOperationPlugin, "metadata.json")
 
 SKGOperationPlugin::SKGOperationPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent),
@@ -247,18 +247,32 @@ bool SKGOperationPlugin::setupActions(SKGDocument* iDocument)
     registerGlobalAction(QStringLiteral("view_open_operation_with_date_not_aligned"), actTmp);
 
     // ------------
-    auto actCleanAlignComment = new QAction(SKGServices::fromTheme(QStringLiteral("draw-freehand"), overlayrun), i18nc("Verb", "Align comment of suboperations of all single operations"), this);
-    connect(actCleanAlignComment, &QAction::triggered, this, &SKGOperationPlugin::onAlignComment);
-    registerGlobalAction(QStringLiteral("clean_align_comment"), actCleanAlignComment);
-
-    auto actCleanAlignComment2 = new QAction(SKGServices::fromTheme(QStringLiteral("draw-freehand"), overlayrun), i18nc("Verb", "Align comment of operations of all single operations"), this);
-    connect(actCleanAlignComment2, &QAction::triggered, this, &SKGOperationPlugin::onAlignComment2);
-    registerGlobalAction(QStringLiteral("clean_align_comment2"), actCleanAlignComment2);
+    actTmp = new QAction(SKGServices::fromTheme(QStringLiteral("exchange-positions"), overlayopen), i18nc("Verb", "Open operations without payees category..."), this);
+    actTmp->setData(QString("skg://skrooge_operation_plugin/?title_icon=view-categories&title=" % SKGServices::encodeForUrl(i18nc("Noun, a list of items", "Sub-operations without payees category")) %
+                            "&operationWhereClause=" % SKGServices::encodeForUrl(QStringLiteral("id IN (SELECT v_suboperation_consolidated.i_OPID FROM v_suboperation_consolidated INNER JOIN payee ON v_suboperation_consolidated.r_payee_id=payee.id WHERE payee.r_category_id!=0 AND v_suboperation_consolidated.r_category_id!=payee.r_category_id AND i_NBSUBOPERATIONS=1)"))));
+    connect(actTmp, &QAction::triggered, SKGMainPanel::getMainPanel(), [ = ]() {
+        SKGMainPanel::getMainPanel()->SKGMainPanel::openPage();
+    });
+    registerGlobalAction(QStringLiteral("view_open_suboperations_without_payee_category"), actTmp);
 
     // ------------
-    auto actCleanAlignDate = new QAction(SKGServices::fromTheme(QStringLiteral("view-pim-calendar"), overlayrun), i18nc("Verb", "Align date of suboperations of all operations"), this);
-    connect(actCleanAlignDate, &QAction::triggered, this, &SKGOperationPlugin::onAlignDate);
-    registerGlobalAction(QStringLiteral("clean_align_date"), actCleanAlignDate);
+    auto actAlignComment = new QAction(SKGServices::fromTheme(QStringLiteral("draw-freehand"), overlayrun), i18nc("Verb", "Align comment of suboperations of all single operations"), this);
+    connect(actAlignComment, &QAction::triggered, this, &SKGOperationPlugin::onAlignComment);
+    registerGlobalAction(QStringLiteral("align_comment"), actAlignComment);
+
+    auto actAlignComment2 = new QAction(SKGServices::fromTheme(QStringLiteral("draw-freehand"), overlayrun), i18nc("Verb", "Align comment of operations of all single operations"), this);
+    connect(actAlignComment2, &QAction::triggered, this, &SKGOperationPlugin::onAlignComment2);
+    registerGlobalAction(QStringLiteral("align_comment2"), actAlignComment2);
+
+    // ------------
+    auto actAlignDate = new QAction(SKGServices::fromTheme(QStringLiteral("view-pim-calendar"), overlayrun), i18nc("Verb", "Align date of suboperations of all operations"), this);
+    connect(actAlignDate, &QAction::triggered, this, &SKGOperationPlugin::onAlignDate);
+    registerGlobalAction(QStringLiteral("align_date"), actAlignDate);
+
+    auto actAlignCategory = new QAction(SKGServices::fromTheme(QStringLiteral("view-pim-calendar"), overlayrun), i18nc("Verb", "Align the category of all single operations with the category of their payee"), this);
+    connect(actAlignCategory, &QAction::triggered, this, &SKGOperationPlugin::onAlignWithCategoryOfPaye);
+    registerGlobalAction(QStringLiteral("align_category"), actAlignCategory);
+
 
     // ------------
     actTmp = new QAction(SKGServices::fromTheme(QStringLiteral("exchange-positions"), overlayopen), i18nc("Verb", "Open operations in groups with only one operation..."), this);
@@ -353,15 +367,19 @@ void SKGOperationPlugin::refresh()
         int nb = selection.count();
         bool onOperation = (nb > 0 && selection.at(0).getRealTable() == QStringLiteral("operation"));
 
-        QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_align_date"));
+        QAction* act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("align_date"));
         act->setText(onOperation ? i18nc("Verb", "Align date of suboperations of selected single operations") : i18nc("Verb", "Align date of suboperations of all single operations"));
         act->setData(onOperation);
 
-        act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_align_comment2"));
+        act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("align_comment2"));
         act->setText(onOperation ? i18nc("Verb", "Align comment of operations of selected single operations") : i18nc("Verb", "Align comment of operations of all single operations"));
         act->setData(onOperation);
 
-        act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("clean_align_comment"));
+        act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("align_category"));
+        act->setText(onOperation ? i18nc("Verb", "Align the category of all selected single operations with the category of their payee") : i18nc("Verb", "Align the category of all single operations with the category of their payee"));
+        act->setData(onOperation);
+
+        act = SKGMainPanel::getMainPanel()->getGlobalAction(QStringLiteral("align_comment"));
         act->setText(onOperation ? i18nc("Verb", "Align comment of suboperations of selected single operations") : i18nc("Verb", "Align comment of suboperations of all single operations"));
         act->setData(onOperation);
 
@@ -1419,13 +1437,13 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
                 }
                 {
                     SKGAdvice::SKGAdviceAction a;
-                    a.Title = QStringLiteral("skg://clean_align_comment");
+                    a.Title = QStringLiteral("skg://align_comment");
                     a.IsRecommended = true;
                     autoCorrections.push_back(a);
                 }
                 {
                     SKGAdvice::SKGAdviceAction a;
-                    a.Title = QStringLiteral("skg://clean_align_comment2");
+                    a.Title = QStringLiteral("skg://align_comment2");
                     a.IsRecommended = false;
                     autoCorrections.push_back(a);
                 }
@@ -1462,7 +1480,7 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
                 }
                 {
                     SKGAdvice::SKGAdviceAction a;
-                    a.Title = QStringLiteral("skg://clean_align_date");
+                    a.Title = QStringLiteral("skg://align_date");
                     a.IsRecommended = true;
                     autoCorrections.push_back(a);
                 }
@@ -1477,6 +1495,34 @@ SKGAdviceList SKGOperationPlugin::advice(const QStringList& iIgnoredAdvice)
             mutex.unlock();
         }, false);
     }
+
+    // Check operations having category not aligned with the category of the payee
+    if (!iIgnoredAdvice.contains(QStringLiteral("skgpayeeplugin_subop_with_wrong_wategory"))) {
+        bool exist = false;
+        m_currentBankDocument->existObjects(QStringLiteral("v_suboperation_consolidated INNER JOIN payee ON v_suboperation_consolidated.r_payee_id=payee.id"), QStringLiteral("payee.r_category_id!=0 AND v_suboperation_consolidated.r_category_id!=payee.r_category_id"), exist);
+        if (exist) {
+            SKGAdvice ad;
+            ad.setUUID(QStringLiteral("skgpayeeplugin_subop_with_wrong_wategory"));
+            ad.setPriority(3);
+            ad.setShortMessage(i18nc("Advice on making the best (short)", "Category not aligned with payee's category"));
+            ad.setLongMessage(i18nc("Advice on making the best (long)", "Some operations don't have the category aligned with the category of the payee."));
+            SKGAdvice::SKGAdviceActionList autoCorrections;
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = QStringLiteral("skg://view_open_suboperations_without_payee_category");
+                autoCorrections.push_back(a);
+            }
+            {
+                SKGAdvice::SKGAdviceAction a;
+                a.Title = QStringLiteral("skg://align_category");
+
+                autoCorrections.push_back(a);
+            }
+            ad.setAutoCorrections(autoCorrections);
+            output.push_back(ad);
+        }
+    }
+
     do {
         QThread::yieldCurrentThread();
         if (nbConcurrentCheckExecuted == nbConcurrentCheckTargeted) {
@@ -1649,6 +1695,41 @@ void SKGOperationPlugin::onAlignDate()
     SKGMainPanel::displayErrorMessage(err);
 }
 
+void SKGOperationPlugin::onAlignWithCategoryOfPaye()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(10, err)
+
+    {
+        SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+        auto* act = qobject_cast< QAction* >(sender());
+        if ((act == nullptr) || !act->data().toBool()) {
+            // Clear selection to enable the model "All"
+            selection.clear();
+        }
+        SKGBEGINTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Align the category of all single operations with the category of their payee"), err)
+        QString q = QStringLiteral("UPDATE suboperation SET r_category_id=(SELECT p.r_category_id FROM v_suboperation_consolidated so INNER JOIN payee p ON so.r_payee_id=p.id WHERE p.r_category_id!=0 AND so.r_category_id!=p.r_category_id) WHERE suboperation.id IN (SELECT so.id FROM v_suboperation_consolidated so INNER JOIN payee p ON so.r_payee_id=p.id WHERE p.r_category_id!=0 AND so.r_category_id!=p.r_category_id AND so.i_NBSUBOPERATIONS)");
+        int nb = selection.count();
+        if (nb == 0) {
+            err = m_currentBankDocument->executeSqliteOrder(q);
+        } else {
+            for (int i = 0; !err && i < nb; ++i) {
+                SKGOperationObject op(selection.at(i));
+                err = m_currentBankDocument->executeSqliteOrder(q % " AND rd_operation_id=" % SKGServices::intToString(op.getID()));
+            }
+        }
+    }
+
+    // status bar
+    IFOKDO(err, SKGError(0, i18nc("Message for successful user action", "Categories aligned.")))
+    else {
+        err.addError(ERR_FAIL, i18nc("Error message", "Categories alignment failed"));
+    }
+
+    // Display error
+    SKGMainPanel::displayErrorMessage(err);
+}
+
 void SKGOperationPlugin::onMergeSubOperations()
 {
     SKGError err;
