@@ -36,7 +36,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGReportPluginFactory, registerPlugin<SKGReportPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGReportPlugin, "metadata.json")
 
 SKGReportPlugin::SKGReportPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
