@@ -13,6 +13,8 @@
 #include <kaboutdata.h>
 #include <kactioncollection.h>
 #include <kpluginfactory.h>
+#include <ktoolbarpopupaction.h>
+
 #include <qstandardpaths.h>
 
 #include "skgdocumentbank.h"
@@ -28,10 +30,10 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGScheduledPluginFactory, registerPlugin<SKGScheduledPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGScheduledPlugin, "metadata.json")
 
 SKGScheduledPlugin::SKGScheduledPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
-    SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr), m_counterAdvice(0)
+    SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr), m_counterAdvice(0), m_assignScheduleMenu(nullptr)
 {
     Q_UNUSED(iWidget)
     SKGTRACEINFUNC(10)
@@ -55,6 +57,9 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument)
     setComponentName(QStringLiteral("skrooge_scheduled"), title());
     setXMLFile(QStringLiteral("skrooge_scheduled.rc"));
 
+    QStringList listOperation;
+    listOperation << QStringLiteral("operation");
+
     // Create yours actions here
     auto actScheduleOperation = new QAction(SKGServices::fromTheme(icon()), i18nc("Verb, create a scheduled operation", "Schedule"), this);
     connect(actScheduleOperation, &QAction::triggered, this, &SKGScheduledPlugin::onScheduleOperation);
@@ -65,9 +70,87 @@ bool SKGScheduledPlugin::setupActions(SKGDocument* iDocument)
     connect(actSkipScheduledOperation, &QAction::triggered, this, &SKGScheduledPlugin::onSkipScheduledOperations);
     registerGlobalAction(QStringLiteral("skip_scheduled_operations"), actSkipScheduledOperation, QStringList() << QStringLiteral("recurrentoperation"), 1, -1, 410);
 
+    auto actAssignScheduleAction = new KToolBarPopupAction(SKGServices::fromTheme(QStringLiteral("edit-guides")), i18nc("Verb, action to assign a schedule", "Assign schedule"), this);
+    m_assignScheduleMenu = actAssignScheduleAction->menu();
+    connect(m_assignScheduleMenu, &QMenu::aboutToShow, this, &SKGScheduledPlugin::onShowAssignScheduleMenu);
+    actAssignScheduleAction->setStickyMenu(false);
+    actAssignScheduleAction->setData(1);
+    registerGlobalAction(QStringLiteral("edit_assign_schedule"), actAssignScheduleAction, listOperation, 1, -1, 412);
+
     return true;
 }
 
+void SKGScheduledPlugin::onShowAssignScheduleMenu()
+{
+    if ((m_assignScheduleMenu != nullptr) && (m_currentBankDocument != nullptr)) {
+        // Clean Menu
+        QMenu* m = m_assignScheduleMenu;
+        m->clear();
+
+        // Search templates
+        SKGStringListList listTmp;
+        m_currentBankDocument->executeSelectSqliteOrder(
+            QStringLiteral("SELECT t_displayname, id FROM v_recurrentoperation_displayname ORDER BY t_displayname"),
+            listTmp);
+
+        // Build menus
+        int count = 0;
+        bool fav = true;
+        int nb = listTmp.count();
+        for (int i = 1; i < nb; ++i) {
+            // Add more sub menu
+            if (count == 8) {
+                m = m->addMenu(i18nc("More items in a menu", "More"));
+                count = 0;
+            }
+            count++;
+
+            // Add actions
+            QAction* act = m->addAction(SKGServices::fromTheme(QStringLiteral("edit-guides")), listTmp.at(i).at(0));
+            if (act != nullptr) {
+                act->setData(listTmp.at(i).at(1));
+                connect(act, &QAction::triggered, this, &SKGScheduledPlugin::onAssignScheduleMenu);
+            }
+        }
+    }
+}
+
+void SKGScheduledPlugin::onAssignScheduleMenu()
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(10, err)
+    auto* act = qobject_cast<QAction*>(sender());
+    if (act != nullptr) {
+        // Get template
+        auto id = act->data().toString();
+
+        // Get Selection
+        if ((SKGMainPanel::getMainPanel() != nullptr) && (m_currentBankDocument != nullptr)) {
+            SKGObjectBase::SKGListSKGObjectBase selection = SKGMainPanel::getMainPanel()->getSelectedObjects();
+            int nb = selection.count();
+            {
+                SKGBEGINPROGRESSTRANSACTION(*m_currentBankDocument, i18nc("Noun, name of the user action", "Assign schedule"), err, nb)
+                for (int i = 0; !err && i < nb; ++i) {
+                    SKGOperationObject operationObj(selection.at(i));
+                    IFOKDO(err, operationObj.setAttribute("r_recurrentoperation_id", id))
+                    IFOKDO(err, operationObj.save(true, false))
+
+                    IFOKDO(err, m_currentBankDocument->stepForward(i + 1))
+                }
+            }
+
+            // status bar
+            IFOK(err) {
+                err = SKGError(0, i18nc("Successful message after an user action", "Schedule assigned."));
+            } else {
+                err.addError(ERR_FAIL, i18nc("Error message",  "Schedule assignment failed"));
+            }
+        }
+        // Display error
+        SKGMainPanel::displayErrorMessage(err);
+    }
+
+}
 void SKGScheduledPlugin::refresh()
 {
     SKGTRACEINFUNC(10)
