@@ -32,7 +32,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGSearchPluginFactory, registerPlugin<SKGSearchPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGSearchPlugin, "metadata.json")
 
 SKGSearchPlugin::SKGSearchPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/) :
     SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
