@@ -32,7 +32,7 @@
 /**
  * This plugin factory.
  */
-K_PLUGIN_FACTORY(SKGUnitPluginFactory, registerPlugin<SKGUnitPlugin>();)
+K_PLUGIN_CLASS_WITH_JSON(SKGUnitPlugin, "metadata.json")
 
 SKGUnitPlugin::SKGUnitPlugin(QWidget* iWidget, QObject* iParent, const QVariantList& /*iArg*/)
     : SKGInterfacePlugin(iParent), m_currentBankDocument(nullptr)
