@@ -11,11 +11,10 @@
 #include "skgunitpluginwidget.h"
 
 #include <klocalizedstring.h>
-#include <kns3/downloaddialog.h>
-#include <kns3/uploaddialog.h>
 #include <krun.h>
 #include <kzip.h>
 
+#include <kns3/qtquickdialogwrapper.h>
 #include <qdir.h>
 #include <qdom.h>
 #include <qevent.h>
@@ -874,7 +873,7 @@ void SKGUnitPluginWidget::onSourceChanged()
 
 void SKGUnitPluginWidget::onGetNewHotStuff()
 {
-    QPointer<KNS3::DownloadDialog> dialog = new KNS3::DownloadDialog(QStringLiteral("skrooge_unit.knsrc"), this);
+    QPointer<KNS3::QtQuickDialogWrapper> dialog = new KNS3::QtQuickDialogWrapper(QStringLiteral("skrooge_unit.knsrc"), this);
     dialog->exec();
 
     fillSourceList();
@@ -893,17 +892,11 @@ void SKGUnitPluginWidget::onPutNewHotStuff()
         zip.close();
 
         // Open dialog
-        QPointer<KNS3::UploadDialog> dialog = new KNS3::UploadDialog(QStringLiteral("skrooge_unit.knsrc"), this);
-
-        dialog->setUploadFile(QUrl::fromLocalFile(zipFileName));
-        dialog->setUploadName(source);
-        dialog->setDescription(i18nc("Default description for the source", "My favorite source of download for units"));
-        dialog->setVersion(QStringLiteral("0.1"));
-        dialog->setChangelog(QStringLiteral("V0.1 - Initial version"));
-        dialog->exec();
-
-        // Delete temporary files
-        QFile(zipFileName).remove();
+        SKGMainPanel::getMainPanel()->displayMessage(i18nc("Upload message",
+                "The package is ready. You can find it here %1. You can now upload it manually.",
+                zipFileName
+                                                          )
+                                                    );
     }
 }
 
