@@ -22,7 +22,7 @@ tempDir='/data'
 
 class Releasor(object):
     def __init__(self, args):
-        self.ubuntuVersions=['focal', 'jammy']
+        self.ubuntuVersions=['jammy', 'kinetic']
         self.workdingDir=os.path.join(tempDir, 'skrooge-release_' + args.version)
         print("# Working directory :" + self.workdingDir)    
         if args.version.endswith(".0") or args.stable:
@@ -63,6 +63,7 @@ class Releasor(object):
             self.logfile.write('### '+' '.join(cmd)+'\n')                
             rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
             if rc == 0:
+                print('# Launch tarme.rb')
                 cmd = ['releaseme/tarme.rb', '--version', args.version, '--origin', 'trunk', 'skrooge']
                 self.logfile.write('### '+' '.join(cmd)+'\n')                
                 rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)
@@ -141,7 +142,7 @@ class Releasor(object):
         self.logfile.write('### '+' '.join(cmd)+'\n')                
         rc = subprocess.call(cmd, stdout=self.logfile, stderr=self.logfile)                                  
         if rc == 0:
-            print("Skrooge "+args.version+" released\n\nHi,\n\nCould you publish the following files in skrooge/"+("stable" if args.stable else "unstable")+"?\n")
+            print("Skrooge "+args.version+" released\n\nHi,\n\nCould you publish the following files in "+("stable" if args.stable else "unstable")+"/skrooge ?\n")
             cmd = ['sha256sum', filename]
             self.logfile.write('### '+' '.join(cmd)+'\n')                
             rc = subprocess.call(cmd)  
