@@ -489,16 +489,16 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                 SKGUnitObject unit(*obj);
                 double amountOneYearBefore = unit.getAmount(QDate::currentDate().addYears(-1));
                 double annualchange = 100.0 * (unit.getAmount() - amountOneYearBefore) / amountOneYearBefore;
-                if (annualchange >= 15) {
+                if (annualchange >= 10) {
                     return m_iconMuchMore;
                 }
-                if (annualchange <= -15) {
+                if (annualchange <= -10) {
                     return m_iconMuchLess;
                 }
-                if (annualchange >= 5) {
+                if (annualchange > 0) {
                     return m_iconMore;
                 }
-                if (annualchange <= -5) {
+                if (annualchange < 0) {
                     return m_iconLess;
                 }
             }
@@ -791,9 +791,9 @@ QVariant SKGObjectModel::computeData(const QModelIndex& iIndex, int iRole) const
                     if (!toolTipString.isEmpty()) {
                         toolTipString += QStringLiteral("\n\n");
                     }
-                    toolTipString += i18nc("Noun", "Variation sur un mois=%1\n", SKGServices::toPercentageString(oneMonthChange));
-                    toolTipString += i18nc("Noun", "Variation sur six mois=%1\n", SKGServices::toPercentageString(sixMonthChange));
-                    toolTipString += i18nc("Noun", "Variation sur un an=%1\n", SKGServices::toPercentageString(annualchange));
+                    toolTipString += i18nc("Noun", "Variation on the last year = %1\n", SKGServices::toPercentageString(annualchange));
+                    toolTipString += i18nc("Noun", "Variation on the last 6 months = %1 = %2 / year\n", SKGServices::toPercentageString(sixMonthChange), SKGServices::toPercentageString(100.0 * pow(1.0 + sixMonthChange / 100.0, 2.0) - 100.0));
+                    toolTipString += i18nc("Noun", "Variation on the last month = %1 = %2 / year\n", SKGServices::toPercentageString(oneMonthChange), SKGServices::toPercentageString(100.0 * pow(1.0 + oneMonthChange / 100.0, 12.0) - 100.0));
                 }
             }
         } else if (m_operationTable || m_recurrentoperationTable) {
