@@ -18,6 +18,7 @@
 #include <qregularexpression.h>
 #include <qtemporaryfile.h>
 #include <qtextcodec.h>
+#include <qstandardpaths.h>
 
 #include <algorithm>
 
@@ -32,7 +33,7 @@
 
 SKGImportExportManager::SKGImportExportManager(SKGDocumentBank* iDocument,
         QUrl  iFileName)
-    :  m_document(iDocument), m_fileName(std::move(iFileName)),
+    :  m_document(iDocument), m_fileName(iFileName),
        m_defaultAccount(nullptr), m_defaultUnit(nullptr),
        m_importPlugin(nullptr), m_exportPlugin(nullptr)
 {
@@ -443,27 +444,35 @@ void SKGImportExportManager::setImportParameters(const QMap< QString, QString >&
     }
 }
 
+void SKGImportExportManager::loadPlugins()
+{
+    if (m_plugins.isEmpty()) {
+        const auto plugins = KPluginMetaData::findPlugins(QStringLiteral("skrooge/import"));
+        int nb = plugins.count();
+        for (int i = 0; i < nb; ++i) {
+            const auto factory = KPluginFactory::loadFactory(plugins.at(i));
+            const auto pluginInterface = factory.plugin ? factory.plugin->create<SKGImportPlugin>(this) : nullptr;
+            if (pluginInterface != nullptr) {
+                m_plugins.append(pluginInterface);
+            }
+        }
+    }
+}
+
 QString SKGImportExportManager::getParameterDefaultValue(const QString& iParameter)
 {
     QString output;
-    // Search the first plugin having a value for this parameter
-    KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("SKG IMPORT/Plugin"));
-    int nb = offers.count();
+
+    loadPlugins();
+
+    int nb = m_plugins.count();
     for (int i = 0; i < nb && output.isEmpty(); ++i) {
-        KService::Ptr service = offers.at(i);
-        KPluginLoader loader(service->library());
-        KPluginFactory* factory = loader.factory();
-        if (factory != nullptr) {
-            auto* pluginInterface = factory->create<SKGImportPlugin> (nullptr);
-            if (pluginInterface != nullptr) {
-                auto val = pluginInterface->getImportParameters().value(iParameter);
-                if (!val.isEmpty()) {
-                    output = val;
-                } else {
-                    output = pluginInterface->getExportParameters().value(iParameter);
-                }
-                delete pluginInterface;
-            }
+        auto pluginInterface = m_plugins.at(i);
+        auto val = pluginInterface->getImportParameters().value(iParameter);
+        if (!val.isEmpty()) {
+            output = val;
+        } else {
+            output = pluginInterface->getExportParameters().value(iParameter);
         }
     }
     return output;
@@ -481,32 +490,21 @@ QMap< QString, QString > SKGImportExportManager::getImportParameters()
 
 QString SKGImportExportManager::getImportMimeTypeFilter(bool iIncludingAll)
 {
-    QMap<QString, QString> tmp;
-    KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("SKG IMPORT/Plugin"));
-    int nb = offers.count();
-    for (int i = 0; i < nb; ++i) {
-        KService::Ptr service = offers.at(i);
-        QString name = service->name();
-        QString msg = i18nc("Message", "Loading plugin %1/%2: %3...", i + 1, nb, name);
-        SKGTRACEL(1) << msg << SKGENDL;
+    loadPlugins();
 
-        KPluginLoader loader(service->library());
-        KPluginFactory* factory = loader.factory();
-        if (factory != nullptr) {
-            auto* pluginInterface = factory->create<SKGImportPlugin> (nullptr);
-            if (pluginInterface != nullptr) {
-                if (pluginInterface->isImportPossible()) {
-                    QString mime = pluginInterface->getMimeTypeFilter();
-                    if (!mime.isEmpty()) {
-                        QStringList lines = SKGServices::splitCSVLine(mime, '\n');
-                        int nblines = lines.count();
-                        for (int l = 0; l < nblines; ++l) {
-                            QStringList items = SKGServices::splitCSVLine(lines.at(l), '|');
-                            tmp[items.at(1)] = items.at(0);
-                        }
-                    }
+    QMap<QString, QString> tmp;
+    int nb = m_plugins.count();
+    for (int i = 0; i < nb; ++i) {
+        auto pluginInterface = m_plugins.at(i);
+        if (pluginInterface->isImportPossible()) {
+            QString mime = pluginInterface->getMimeTypeFilter();
+            if (!mime.isEmpty()) {
+                QStringList lines = SKGServices::splitCSVLine(mime, '\n');
+                int nblines = lines.count();
+                for (int l = 0; l < nblines; ++l) {
+                    QStringList items = SKGServices::splitCSVLine(lines.at(l), '|');
+                    tmp[items.at(1)] = items.at(0);
                 }
-                delete pluginInterface;
             }
         }
     }
@@ -532,32 +530,21 @@ QString SKGImportExportManager::getImportMimeTypeFilter(bool iIncludingAll)
 
 QString SKGImportExportManager::getExportMimeTypeFilter(bool iIncludingAll)
 {
-    QMap<QString, QString> tmp;
-    KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("SKG IMPORT/Plugin"));
-    int nb = offers.count();
-    for (int i = 0; i < nb; ++i) {
-        KService::Ptr service = offers.at(i);
-        QString name = service->name();
-        QString msg = i18nc("Message", "Loading plugin %1/%2: %3...", i + 1, nb, name);
-        SKGTRACEL(1) << msg << SKGENDL;
+    loadPlugins();
 
-        KPluginLoader loader(service->library());
-        KPluginFactory* factory = loader.factory();
-        if (factory != nullptr) {
-            auto* pluginInterface = factory->create<SKGImportPlugin> (nullptr);
-            if (pluginInterface != nullptr) {
-                if (pluginInterface->isExportPossible()) {
-                    QString mime = pluginInterface->getMimeTypeFilter();
-                    if (!mime.isEmpty()) {
-                        QStringList lines = SKGServices::splitCSVLine(mime, '\n');
-                        int nblines = lines.count();
-                        for (int l = 0; l < nblines; ++l) {
-                            QStringList items = SKGServices::splitCSVLine(lines.at(l), '|');
-                            tmp[items.at(1)] = items.at(0);
-                        }
-                    }
+    QMap<QString, QString> tmp;
+    int nb = m_plugins.count();
+    for (int i = 0; i < nb; ++i) {
+        auto pluginInterface = m_plugins.at(i);
+        if (pluginInterface->isExportPossible()) {
+            QString mime = pluginInterface->getMimeTypeFilter();
+            if (!mime.isEmpty()) {
+                QStringList lines = SKGServices::splitCSVLine(mime, '\n');
+                int nblines = lines.count();
+                for (int l = 0; l < nblines; ++l) {
+                    QStringList items = SKGServices::splitCSVLine(lines.at(l), '|');
+                    tmp[items.at(1)] = items.at(0);
                 }
-                delete pluginInterface;
             }
         }
     }
@@ -585,24 +572,15 @@ QString SKGImportExportManager::getExportMimeTypeFilter(bool iIncludingAll)
 SKGImportPlugin* SKGImportExportManager::getImportPlugin()
 {
     if (m_importPlugin == nullptr) {
-        KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("SKG IMPORT/Plugin"));
-        int nb = offers.count();
-        for (int i = 0; (m_importPlugin == nullptr) && i < nb; ++i) {
-            KService::Ptr service = offers.at(i);
-            QString id = service->property(QStringLiteral("X-Krunner-ID"), QVariant::String).toString();
-            KPluginLoader loader(service->library());
-            KPluginFactory* factory = loader.factory();
-            if (factory != nullptr) {
-                auto* pluginInterface = factory->create<SKGImportPlugin> (this);
-                if (pluginInterface != nullptr) {
-                    if (pluginInterface->isImportPossible()) {
-                        // Import
-                        m_importPlugin = pluginInterface;
-                    }
-                }
-            } else if (m_document != nullptr) {
-                m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()), SKGDocument::Error);
+        loadPlugins();
+
+        int nb = m_plugins.count();
+        for (int i = 0; i < nb && m_importPlugin == nullptr; ++i) {
+            auto pluginInterface = m_plugins.at(i);
+            if (pluginInterface->isImportPossible()) {
+                m_importPlugin = pluginInterface;
             }
+
         }
     }
     return m_importPlugin;
@@ -611,24 +589,15 @@ SKGImportPlugin* SKGImportExportManager::getImportPlugin()
 SKGImportPlugin* SKGImportExportManager::getExportPlugin()
 {
     if (m_exportPlugin == nullptr) {
-        KService::List offers = KServiceTypeTrader::self()->query(QStringLiteral("SKG IMPORT/Plugin"));
-        int nb = offers.count();
-        for (int i = 0; (m_exportPlugin == nullptr) && i < nb; ++i) {
-            KService::Ptr service = offers.at(i);
-            QString id = service->property(QStringLiteral("X-Krunner-ID"), QVariant::String).toString();
-            KPluginLoader loader(service->library());
-            KPluginFactory* factory = loader.factory();
-            if (factory != nullptr) {
-                auto* pluginInterface = factory->create<SKGImportPlugin> (this);
-                if (pluginInterface != nullptr) {
-                    if (pluginInterface->isExportPossible()) {
-                        // Import
-                        m_exportPlugin = pluginInterface;
-                    }
-                }
-            } else if (m_document != nullptr) {
-                m_document->sendMessage(i18nc("An information message",  "Loading plugin %1 failed because the factory could not be found in %2", id, service->library()), SKGDocument::Error);
+        loadPlugins();
+
+        int nb = m_plugins.count();
+        for (int i = 0; i < nb && m_exportPlugin == nullptr; ++i) {
+            auto pluginInterface = m_plugins.at(i);
+            if (pluginInterface->isExportPossible()) {
+                m_exportPlugin = pluginInterface;
             }
+
         }
     }
     return m_exportPlugin;
@@ -937,4 +906,124 @@ SKGError SKGImportExportManager::findAndGroupTransfers(int& oNbOperationsMerged,
     return findAndGroupTransfers(oNbOperationsMerged, iOnCurrentlyImport ? QStringLiteral("A.t_imported='T' AND B.t_imported='T'") : QLatin1String(""));
 }
 
+SKGError SKGImportExportManager::getXMLDocument(QDomElement& oDocument)
+{
+    SKGError err;
+    SKGTRACEINFUNCRC(2, err)
 
+    // Open file
+    QFile file(getLocalFileName());
+    if (!file.open(QIODevice::ReadOnly)) {
+        err.setReturnCode(ERR_INVALIDARG).setMessage(i18nc("Error message",  "Open file '%1' failed", getFileName().toDisplayString()));
+    } else {
+        QDomDocument doc;
+
+        // Set the file without uncompression
+        QString errorMsg;
+        int errorLine = 0;
+        int errorCol = 0;
+        bool contentOK = doc.setContent(file.readAll(), &errorMsg, &errorLine, &errorCol);
+        file.close();
+
+        if (!contentOK) {
+            err.setReturnCode(ERR_ABORT).setMessage(i18nc("Error message",  "%1-%2: '%3'", errorLine, errorCol, errorMsg)).addError(ERR_INVALIDARG, i18nc("Error message",  "Invalid XML content in file '%1'", getFileName().toDisplayString()));
+        } else {
+            // Get root
+            oDocument = doc.documentElement();
+        }
+    }
+
+    return err;
+}
+
+SKGError SKGImportExportManager::importItems(QDomElement& docElem)
+{
+    SKGError err;
+    if (docElem.isNull()) {
+        return err;
+    }
+    auto type = docElem.tagName().remove(QStringLiteral("list_"));
+    QDomNodeList items = docElem.elementsByTagName(type);
+    int nb = items.count();
+    if (nb > 0) {
+        SKGTRACEINRC(10, "SKGImportPluginXml::importFile-" + type, err)
+        err = getDocument()->beginTransaction("#INTERNAL#" % i18nc("Import step", "Import %1", type), nb);
+        for (int j = 0; !err && j < nb; ++j) {
+            QDomNode node = items.at(j);
+            QDomElement item = node.toElement();
+            SKGObjectBase* obj;
+            if (type == "category") {
+                obj = new SKGCategoryObject(getDocument());
+            } else if (type == "unit") {
+                obj = new SKGUnitObject(getDocument());
+            } else if (type == "unitvalue") {
+                obj = new SKGUnitValueObject(getDocument());
+            } else if (type == "refund") {
+                obj = new SKGTrackerObject(getDocument());
+            } else if (type == "bank") {
+                obj = new SKGBankObject(getDocument());
+            } else if (type == "rule") {
+                obj = new SKGRuleObject(getDocument());
+            } else if (type == "account") {
+                obj = new SKGAccountObject(getDocument());
+            } else if (type == "payee") {
+                obj = new SKGPayeeObject(getDocument());
+            } else if (type == "operation") {
+                obj = new SKGOperationObject(getDocument());
+            } else if (type == "suboperation") {
+                obj = new SKGSubOperationObject(getDocument());
+            } else if (type == "budget") {
+                obj = new SKGBudgetObject(getDocument());
+            } else if (type == "budgetrule") {
+                obj = new SKGBudgetRuleObject(getDocument());
+            } else if (type == "interest") {
+                obj = new SKGInterestObject(getDocument());
+            } else if (type == "recurrentoperation") {
+                obj = new SKGRecurrentOperationObject(getDocument());
+            } else if (type == "rule") {
+                obj = new SKGRuleObject(getDocument());
+            } else {
+                obj = new SKGObjectBase(getDocument(), type);
+            }
+
+            auto attributes = item.attributes();
+            int nb2 = attributes.count();
+            for (int i = 0 ; !err && i < nb2; ++i) {
+                auto att = attributes.item(i);
+
+                auto name = att.nodeName();
+                if (name != "id" && name != "r_recurrentoperation_id") {
+                    auto val = att.nodeValue();
+                    if (name.startsWith(QStringLiteral("rd_")) || name.startsWith(QStringLiteral("rc_")) || name.startsWith(QStringLiteral("r_"))) {
+                        auto tmp = name.split("_");
+                        if (m_mapIdObject.contains(tmp[1] + "-" + val)) {
+                            val = SKGServices::intToString(m_mapIdObject[tmp[1] + "-" + val].getID());
+                        } else {
+                            val = "";
+                        }
+                    }
+                    IFOKDO(err, obj->setAttribute(name, val))
+                }
+            }
+            if (type == "operation") {
+                QString str;
+                QTextStream stream(&str);
+                node.save(stream, 0);
+                QByteArray hash = QCryptographicHash::hash(str.toUtf8(), QCryptographicHash::Md5);
+                IFOKDO(err, static_cast<SKGOperationObject*>(obj)->setImportID("XML-" + QString(hash.toHex())))
+            }
+            if (obj->exist()) {
+                IFOKDO(err, obj->load())
+            } else {
+                IFOKDO(err, obj->save(true, true))
+            }
+            m_mapIdObject[type + "-" + item.attribute(QStringLiteral("id"))] = *obj;
+
+            delete obj;
+
+            IFOKDO(err, getDocument()->stepForward(j + 1))
+        }
+        SKGENDTRANSACTION(getDocument(),  err)
+    }
+    return err;
+}
