@@ -14,6 +14,7 @@
 #include <qobject.h>
 #include <qstringlist.h>
 #include <qurl.h>
+#include <qdom.h>
 
 #include "skgaccountobject.h"
 #include "skgbankmodeler_export.h"
@@ -37,7 +38,7 @@ public:
      * @param iDocument the document
      * @param iFileName the file name
      */
-    explicit SKGImportExportManager(SKGDocumentBank* iDocument,
+    explicit SKGImportExportManager(SKGDocumentBank* iDocument = nullptr,
                                     QUrl  iFileName = QUrl(QLatin1String("")));
 
     /**
@@ -143,14 +144,14 @@ public:
      * Get the default value of a parameter
      * @param iParameter the parameter
      */
-    static QString getParameterDefaultValue(const QString& iParameter);
+    QString getParameterDefaultValue(const QString& iParameter);
 
     /**
      * Get the mime type filter for import
      * @param iIncludingAll to include the "All supported format"
      * @return the mime type filter
      */
-    static QString getImportMimeTypeFilter(bool iIncludingAll = true);
+    QString getImportMimeTypeFilter(bool iIncludingAll = true);
 
     /**
      * Import the file in the document
@@ -164,7 +165,7 @@ public:
      * @param iIncludingAll to include the "All supported format"
      * @return the mime type filter
      */
-    static QString getExportMimeTypeFilter(bool iIncludingAll = true);
+    QString getExportMimeTypeFilter(bool iIncludingAll = true);
 
     /**
      * Export the file in the document
@@ -275,6 +276,22 @@ public:
      */
     QList<QPair<SKGAccountObject, double>> getAccountsToCheck();
 
+    /**
+     * Get the document as an XML object
+     * @param oDocument The output XML document.
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    SKGError getXMLDocument(QDomElement& oDocument);
+
+    /**
+     * Import a XML document
+     * @param docElem The document to import.
+     * @return an object managing the error.
+     *   @see SKGError
+     */
+    SKGError importItems(QDomElement& docElem);
+
 private:
     Q_DISABLE_COPY(SKGImportExportManager)
 
@@ -282,6 +299,8 @@ private:
     SKGImportPlugin* getImportPlugin();
     SKGImportPlugin* getExportPlugin();
 
+    void loadPlugins();
+    QMap<QString, SKGObjectBase> m_mapIdObject;
     SKGDocumentBank* m_document;
     QUrl m_fileName;
     QString m_localFileName;
@@ -293,8 +312,8 @@ private:
     bool m_since_last_import;
     SKGImportPlugin* m_importPlugin;
     SKGImportPlugin* m_exportPlugin;
-
     QList<QPair<SKGAccountObject, double>> m_AccountToCheck;
+    QList<SKGImportPlugin*> m_plugins;
 };
 
 #endif
