@@ -11,7 +11,7 @@
 #include "skgimportplugin.h"
 
 SKGImportPlugin::SKGImportPlugin(QObject* iImporter)
-    : KParts::Plugin(iImporter), m_importer(qobject_cast< SKGImportExportManager * >(iImporter))
+    : QObject(), m_importer(qobject_cast< SKGImportExportManager * >(iImporter))
 {}
 SKGImportPlugin::~SKGImportPlugin()
     = default;
