@@ -9,18 +9,15 @@
 * This file is a plugin interface definition.
 *
 * @author Stephane MANKOWSKI / Guillaume DE BURE
- */
-#include <kparts/plugin.h>
-
+*/
 #include "skgbankmodeler_export.h"
 #include "skgerror.h"
 #include "skgimportexportmanager.h"
 
-
 /**
  * This file is a plugin interface definition.
  */
-class SKGBANKMODELER_EXPORT SKGImportPlugin : public KParts::Plugin
+class SKGBANKMODELER_EXPORT SKGImportPlugin: public QObject
 {
     Q_OBJECT
 public:
