@@ -59,7 +59,7 @@ private:
     QWidget* mOriginalParent;
 };
 
-KDatePickerPopup::KDatePickerPopup(Items iItems, const QDate iDate, QWidget* iParent)
+KDatePickerPopup::KDatePickerPopup(Items iItems, QDate iDate, QWidget* iParent)
     : QMenu(iParent)
 {
     mItems = iItems;
@@ -82,27 +82,27 @@ void KDatePickerPopup::buildMenu()
     }
     clear();
 
-    if (mItems & DatePicker) {
+    if ((mItems & DatePicker) != 0u) {
         addAction(new KDatePickerAction(mDatePicker, this));
 
-        if ((mItems & NoDate) || (mItems & Words)) {
+        if ((mItems & NoDate) != 0u || (mItems & Words) != 0u) {
             addSeparator();
         }
     }
 
-    if (mItems & Words) {
+    if ((mItems & Words) != 0u) {
         addAction(i18nc("@option yesterday", "&Yesterday"), this, &KDatePickerPopup::slotYesterday);
         addAction(i18nc("@option today", "&Today"), this, &KDatePickerPopup::slotToday);
         addAction(i18nc("@option tomorrow", "To&morrow"), this, &KDatePickerPopup::slotTomorrow);
         addAction(i18nc("@option next week", "Next &Week"), this, &KDatePickerPopup::slotNextWeek);
         addAction(i18nc("@option next month", "Next M&onth"), this, &KDatePickerPopup::slotNextMonth);
 
-        if (mItems & NoDate) {
+        if ((mItems & NoDate) != 0u) {
             addSeparator();
         }
     }
 
-    if (mItems & NoDate) {
+    if ((mItems & NoDate) != 0u) {
         addAction(i18nc("@option do not specify a date", "No Date"), this, &KDatePickerPopup::slotNoDate);
     }
 }
@@ -112,7 +112,7 @@ KDatePicker* KDatePickerPopup::datePicker() const
     return mDatePicker;
 }
 
-void KDatePickerPopup::setDate(const QDate date)
+void KDatePickerPopup::setDate(QDate date)
 {
     mDatePicker->setDate(date);
 }
@@ -125,7 +125,7 @@ void KDatePickerPopup::setItems(int items)
 }
 #endif
 
-void KDatePickerPopup::slotDateChanged(const QDate date)
+void KDatePickerPopup::slotDateChanged(QDate date)
 {
     emit dateChanged(date);
     hide();
