@@ -30,8 +30,6 @@
 #include <qdatetime.h>
 #include <qstringlist.h>
 
-#define LOCALTEST
-
 namespace KPIM
 {
 
@@ -53,7 +51,7 @@ KDateValidator::KDateValidator(QObject* iParent)
     : QValidator(iParent), d(new KDateValidatorPrivate)
 {
     // Check if we can use the QLocale::ShortFormat
-    d->mAlternativeDateFormatToUse = QLocale(LOCALTEST).dateFormat(QLocale::ShortFormat);
+    d->mAlternativeDateFormatToUse = QLocale().dateFormat(QLocale::ShortFormat);
     if (!d->mAlternativeDateFormatToUse.contains(QStringLiteral("yyyy"))) {
         d->mAlternativeDateFormatToUse = d->mAlternativeDateFormatToUse.replace(QStringLiteral("yy"), QStringLiteral("yyyy"));
     }
@@ -77,7 +75,7 @@ QValidator::State KDateValidator::validate(QString& str, int& /*pos*/) const
         return Acceptable;
     }
 
-    QDate date = QLocale(LOCALTEST).toDate(str, d->mAlternativeDateFormatToUse);
+    QDate date = QLocale().toDate(str, d->mAlternativeDateFormatToUse);
     if (date.isValid()) {
         return Acceptable;
     }
@@ -93,7 +91,7 @@ void KDateValidator::fixup(QString& input) const
 
     QDate result = SKGServices::partialStringToDate(input, d->behavior == FixupBackward);
     if (result.isValid()) {
-        input = QLocale(LOCALTEST).toString(result, d->mAlternativeDateFormatToUse);
+        input = QLocale().toString(result, d->mAlternativeDateFormatToUse);
     }
 }
 
