@@ -126,6 +126,11 @@ public:
      */
     virtual QDockWidget* getDockWidget();
 
+    /**
+     * Initialize the preferences. This is use full for settings stored in the document
+     */
+    virtual void initPreferences();
+
     /**
      * The preference widget of the plugin.
      * @return The preference widget of the plugin
