@@ -1,18 +1,7 @@
 /***************************************************************************
- *   Copyright (C) 2020 by S. MANKOWSKI / G. DE BURE support@mankowski.fr  *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- *   This program is distributed in the hope that it will be useful,       *
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
- *   GNU General Public License for more details.                          *
- *                                                                         *
- *   You should have received a copy of the GNU General Public License     *
- *   along with this program. If not, see <https://www.gnu.org/licenses/>  *
+ * SPDX-FileCopyrightText: 2022 S. MANKOWSKI stephane@mankowski.fr
+ * SPDX-FileCopyrightText: 2022 G. DE BURE support@mankowski.fr
+ * SPDX-License-Identifier: GPL-3.0-or-later
  ***************************************************************************/
 /** @file
  * This file is a proxy model with better filter mechanism.
@@ -21,7 +10,7 @@
  */
 #include "skgsortfilterproxymodel.h"
 
-#include <qregexp.h>
+#include <qregularexpression.h>
 
 #include "skgobjectmodelbase.h"
 #include "skgservices.h"
@@ -343,8 +332,8 @@ bool SKGSortFilterProxyModel::filterAcceptsRowWords(int source_row, const QModel
                             output = (var == QVariant(word));
                         } else if (op == QStringLiteral("#")) {
                             QVariant var = model->data(index0, Qt::UserRole);
-                            QRegExp pattern(word, Qt::CaseInsensitive, QRegExp::RegExp2);
-                            output = pattern.exactMatch(var.toString());
+                            QRegularExpression pattern(QRegularExpression::anchoredPattern(word), QRegularExpression::CaseInsensitiveOption);
+                            output = pattern.match(var.toString()).hasMatch();
                         }
                     }
                 }
