@@ -53,19 +53,37 @@ SKGTabPage::~SKGTabPage()
 bool SKGTabPage::close(bool iForce)
 {
     SKGTRACEINFUNC(5)
+#ifdef SKG_KF_5100
+    int conf = KMessageBox::PrimaryAction;
+#else
     int conf = KMessageBox::Yes;
+#endif
+
     if (!iForce && isPin()) {
         QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+#ifdef SKG_KF_5100
+        conf = KMessageBox::questionTwoActions(this,
+                                               i18nc("Question", "Do you really want to close this pinned page?"),
+                                               i18nc("Question", "Pinned page"),
+                                               KStandardGuiItem::apply(),
+                                               KStandardGuiItem::cancel(),
+                                               QStringLiteral("closepinnedpage"));
+#else
         conf = KMessageBox::questionYesNo(this,
                                           i18nc("Question", "Do you really want to close this pinned page?"),
                                           i18nc("Question", "Pinned page"),
                                           KStandardGuiItem::yes(),
                                           KStandardGuiItem::no(),
                                           QStringLiteral("closepinnedpage"));
+#endif
         QApplication::restoreOverrideCursor();
     }
     overwrite();
+#ifdef SKG_KF_5100
+    if (conf == KMessageBox::SecondaryAction) {
+#else
     if (conf == KMessageBox::No) {
+#endif
         return false;
     }
     return QWidget::close();
@@ -155,19 +173,34 @@ void SKGTabPage::overwrite(bool iUserConfirmation)
                 SKGTRACEL(20) << "currentState  =[" << currentState << ']' << SKGENDL;
                 if (currentState != oldState) {
                     QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+#ifdef SKG_KF_5100
+                    int conf = KMessageBox::PrimaryAction;
+#else
                     int conf = KMessageBox::Yes;
-                    KMessageBox::ButtonCode button;
-                    SKGTRACEL(10) << (KMessageBox::shouldBeShownYesNo(QStringLiteral("updateBookmarkOnClose"), button) ? "updateBookmarkOnClose: Ask confirmation" : "updateBookmarkOnClose: Do not ask confirmation") << SKGENDL;
+#endif
                     if (iUserConfirmation && !oldState.isEmpty()) {
+#ifdef SKG_KF_5100
+                        conf = KMessageBox::questionTwoActions(this,
+                                                               i18nc("Question", "Bookmark '%1' has been modified. Do you want to update it with the current state?", fullname),
+                                                               i18nc("Question", "Bookmark has been modified"),
+                                                               KStandardGuiItem::apply(),
+                                                               KStandardGuiItem::cancel(),
+                                                               QStringLiteral("updateBookmarkOnClose"));
+#else
                         conf = KMessageBox::questionYesNo(this,
                                                           i18nc("Question", "Bookmark '%1' has been modified. Do you want to update it with the current state?", fullname),
                                                           i18nc("Question", "Bookmark has been modified"),
                                                           KStandardGuiItem::yes(),
                                                           KStandardGuiItem::no(),
                                                           QStringLiteral("updateBookmarkOnClose"));
+#endif
                     }
                     QApplication::restoreOverrideCursor();
+#ifdef SKG_KF_5100
+                    if (conf == KMessageBox::PrimaryAction) {
+#else
                     if (conf == KMessageBox::Yes) {
+#endif
                         SKGError err;
                         {
                             SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Bookmark update '%1'", fullname), err)
@@ -193,20 +226,34 @@ void SKGTabPage::overwrite(bool iUserConfirmation)
             oldState.remove('\n');
             if (currentState != oldState) {
                 QApplication::setOverrideCursor(QCursor(Qt::ArrowCursor));
+#ifdef SKG_KF_5100
+                int conf = KMessageBox::PrimaryAction;
+#else
                 int conf = KMessageBox::Yes;
-                KMessageBox::ButtonCode button;
-                SKGTRACEL(10) << (KMessageBox::shouldBeShownYesNo(QStringLiteral("updateContextOnClose"), button) ? "updateBookmarkOnClose: Ask confirmation" : "updateBookmarkOnClose: Do not ask confirmation") << SKGENDL;
-
+#endif
                 if (iUserConfirmation && !oldState.isEmpty()) {
+#ifdef SKG_KF_5100
+                    conf = KMessageBox::questionTwoActions(this,
+                                                           i18nc("Question", "Page has been modified. Do you want to update it with the current state?"),
+                                                           i18nc("Question", "Page has been modified"),
+                                                           KStandardGuiItem::apply(),
+                                                           KStandardGuiItem::cancel(),
+                                                           QStringLiteral("updateContextOnClose"));
+#else
                     conf = KMessageBox::questionYesNo(this,
                                                       i18nc("Question", "Page has been modified. Do you want to update it with the current state?"),
                                                       i18nc("Question", "Page has been modified"),
                                                       KStandardGuiItem::yes(),
                                                       KStandardGuiItem::no(),
                                                       QStringLiteral("updateContextOnClose"));
+#endif
                 }
                 QApplication::restoreOverrideCursor();
+#ifdef SKG_KF_5100
+                if (conf == KMessageBox::PrimaryAction) {
+#else
                 if (conf == KMessageBox::Yes) {
+#endif
                     SKGError err;
                     {
                         SKGBEGINLIGHTTRANSACTION(*getDocument(), i18nc("Noun, name of the user action", "Save default state"), err)
