@@ -86,13 +86,6 @@ int main(int argc, char** argv)
     // To use CPU instead CPU for QML (needed for printing)
     qputenv("QMLSCENE_DEVICE", "softwarecontext");
 
-    // https://forum.qt.io/topic/90639/comparing-qt-widgets-app-under-gnome-wayland-using-platform-wayland-egl-to-xcb/10
-    if (qgetenv("XDG_SESSION_TYPE") == QByteArrayLiteral("wayland")) {
-        SKGTRACE << "Warning: disregarding XDG_SESSION_TYPE=wayland" << SKGENDL;
-        SKGTRACE << "To use wayland anyway, please set QT_QPA_PLATFORM=wayland" << SKGENDL;
-        qunsetenv("XDG_SESSION_TYPE");
-    }
-
 #ifdef SKG_WEBENGINE
     // DrKonqi
     // https://www.dvratil.cz/2018/10/drkonqi-and-qtwebengine/
