@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/bash
 
 sikulirun()
 {
@@ -55,7 +55,8 @@ checkDiff()
 
 #initialisation
 unset LANG
-export TESTDIR="/data/skrooge-release_2.28.0/skrooge-2.28.0/tests"
+unset LC_MONETARY
+export TESTDIR="/data/skrooge-release_2.29.0/skrooge-2.29.0/tests"
 export IN="${TESTDIR}/input/"
 export OUT="${TESTDIR}/output/"
 export REF="${TESTDIR}/ref/"
@@ -69,8 +70,8 @@ export SKGNOTUNIQUE=1
 rm -Rf "${KDEHOME}" > /dev/null 2>&1
 
 mkdir -p "${OUT}/${EXE}" > /dev/null 2>&1
-EXEPATH="/data/skrooge-release_2.28.0/skrooge-2.28.0/build/bin"
-LIBPATH="/data/skrooge-release_2.28.0/skrooge-2.28.0/build/lib"
+EXEPATH="/data/skrooge-release_2.29.0/skrooge-2.29.0/build/bin"
+LIBPATH="/data/skrooge-release_2.29.0/skrooge-2.29.0/build/lib"
 
 if [ "$TERM" = "cygwin" ] ; then
   export EXE=${EXE}.exe
@@ -81,7 +82,7 @@ if [ "$TERM" = "msys" ] ; then
     export LIBPATH=`echo "$LIBPATH" | sed -e "s,C:,/c/,g"`
 fi
 
-export EXE="/data/skrooge-release_2.28.0/skrooge-2.28.0/build/bin/"${EXE}
+export EXE="/data/skrooge-release_2.29.0/skrooge-2.29.0/build/bin/"${EXE}
 export PATH="$EXEPATH":"$LIBPATH":$PATH
 
 #kbuildsycoca4
