@@ -36,7 +36,7 @@ int main(int argc, char** argv)
             SKGImportExportManager impmissing(&document1, QUrl::fromLocalFile(QStringLiteral("missingfile.mt940")));
             SKGTESTERROR(QStringLiteral("imp1.importFile"), impmissing.importFile(), false)
 
-            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportmt940/test1.mt940"));
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportmt940/test1.sta"));
             SKGTESTERROR(QStringLiteral("MT940.importFile"), imp1.importFile(), true)
         }
 
@@ -141,14 +141,14 @@ int main(int argc, char** argv)
             // Scope of the transaction
             SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_MT940"), err)
 
-            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportmt940/test1.mt940"));
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportmt940/test1.sta"));
             SKGTESTERROR(QStringLiteral("MT940.importFile"), imp1.importFile(), true)
         }
         {
             // Scope of the transaction
             SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_MT940"), err)
 
-            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportmt940/test1.mt940"));
+            SKGImportExportManager imp1(&document1, QUrl::fromLocalFile(SKGTest::getTestPath(QStringLiteral("IN")) % "/skgtestimportmt940/test1.sta"));
             SKGTESTERROR(QStringLiteral("MT940.importFile"), imp1.importFile(), true)
         }
 
