@@ -40,7 +40,7 @@ int main(int argc, char** argv)
             SKGBEGINTRANSACTION(document1, QStringLiteral("IMPORT_INIT"), err)
             SKGImportExportManager impmissing(&document1, QUrl::fromLocalFile(QStringLiteral("missingfile.qif")));
             SKGTESTERROR(QStringLiteral("imp1.importFile"), impmissing.importFile(), false)
-            SKGImportExportManager::getParameterDefaultValue(QStringLiteral("mapping_date"));
+            impmissing.getParameterDefaultValue(QStringLiteral("mapping_date"));
 
             // Creation bank
             SKGTESTERROR(QStringLiteral("BANK:setName"), bank.setName(QStringLiteral("CREDIT COOP")), true)
