@@ -469,6 +469,10 @@ int main(int argc, char** argv)
             SKGTESTERROR(QStringLiteral("OPE:duplicate"), template1.duplicate(op), true)
             SKGTESTERROR(QStringLiteral("OPE:load"), op.load(), true)
             SKGTEST(QStringLiteral("OPE:d_createdate"), static_cast<unsigned int>(op.getAttribute(QStringLiteral("d_createdate")) != QLatin1String("")), static_cast<unsigned int>(true))
+
+            SKGTESTERROR(QStringLiteral("OPE:setProperty"), op.setProperty("a", "1"), true)
+            SKGTESTERROR(QStringLiteral("OPE:setProperty"), opbasic.setProperty("a", "2"), true)
+
             SKGTESTERROR(QStringLiteral("OPE:mergeAttribute"), op.mergeAttribute(opbasic, SKGOperationObject::PROPORTIONAL), true)
             document1.dump(DUMPOPERATION);
 
